@@ -25,7 +25,7 @@ POE::Session->create(
 		_delay => sub { $_[KERNEL]->delay($_[STATE] => 5) },
 		
 		np => sub {
-			warn Dumper $_[ARG0];
+			warn Dumper @_[ARG0, ARG1, ARG2];
 			$_[HEAP]->{__i}++ == 50
 				?
 					$_[KERNEL]->post(
@@ -35,7 +35,8 @@ POE::Session->create(
 				: 
 					$_[KERNEL]->post(
 						'LASTFM_SUBMIT' => 'now_playing' => 'np',
-						{'artist' => 'Артист11', 'title'  => 'Песня21'}
+						{'artist' => 'Артист11', 'title'  => 'Песня21'},
+						$_[HEAP]->{__i}
 					)
 			;
 		},
